@@ -136,7 +136,11 @@
   "CFUNCTION" actions. Added compatibility entries for Computone Multiport
   serial devices.
 
-    Last updated by Richard Gooch   17-APR-2000: Added "COPY" action.
+    Updated by      Richard Gooch   17-APR-2000: Added "COPY" action.
+
+    Last updated by Richard Gooch   18-APR-2000: Moved some things to header
+  "devfsd.h". Removed special argument "ENTRY" and renamed "INFO" to "EVENT"
+  for "CFUNCTION" action. Bug fix in debug mode with shared objects.
 
 
 */
@@ -165,6 +169,8 @@
 #include <errno.h>
 #include <dlfcn.h>
 #include <karma.h>
+#include "devfsd.h"
+
 
 #ifndef IDE6_MAJOR        /*  In case we're building with an ancient kernel  */
 #  define IDE6_MAJOR      88
@@ -174,7 +180,7 @@
 #endif
 
 
-#define VERSION "1.3.4"
+#define VERSION "1.3.5"
 #define CONFIG_FILE "/etc/devfsd.conf"
 #define MAX_ARGS (6 + 1)
 
@@ -186,6 +192,7 @@
 #error protocol version mismatch. Update your kernel headers
 #endif
 
+#define MKACTION(what,when) (struct action_type) {what, when}
 
 #define AC_PERMISSIONS              0
 #define AC_MODLOAD                  1
@@ -199,12 +206,6 @@
 #define AC_RMOLDCOMPAT              9
 #define AC_RMNEWCOMPAT              10
 
-#define MKACTION(what,when) (struct action_type) {what, when}
-
-#define SYSLOG(level, format, args...) \
-    {if (syslog_is_open) syslog (level, format, ##args); \
-     else fprintf (stderr, format, ## args);}
-
 
 struct permissions_type
 {
@@ -280,6 +281,10 @@ EXTERN_FUNCTION (flag st_expr_expand,
 		  void *info, FILE *errfp) );
 
 
+/*  Public data  */
+flag syslog_is_open = FALSE;
+
+
 /*  Private functions  */
 static void setup_initial_entries ();
 static void read_config (CONST char *filename, flag optional,
@@ -318,7 +323,6 @@ static struct config_entry_struct *last_config = NULL;
 static struct shared_object *first_so = NULL;
 static const char *mount_point = NULL;
 static flag no_syslog = FALSE;
-static flag syslog_is_open = FALSE;
 static char trace_level = 0;
 static flag debug_protocol = FALSE;
 static struct initial_symlink_struct
@@ -640,8 +644,6 @@ static void read_config (CONST char *filename, flag optional,
 	else if ( (strcasecmp (what, "MFUNCTION") == 0) ||
 		  (strcasecmp (what, "CFUNCTION") == 0) )
 	{
-	    struct shared_object *so;
-
 	    new->action.what = (strcasecmp (what, "MFUNCTION") == 0) ?
 		AC_MFUNCTION : AC_CFUNCTION;
 	    num_args -= 3;
@@ -650,13 +652,14 @@ static void read_config (CONST char *filename, flag optional,
 		SYSLOG (LOG_ERR, "missing path and function in \"%s\"\n",line);
 		exit (1);
 	    }
-	    if ( ( so = get_shared_object (p[0]) ) == NULL )
+	    if ( ( new->u.function.so = get_shared_object (p[0]) ) == NULL )
 	    {
 		SYSLOG ( LOG_ERR, "error loading: \"%s\"\t%s\n",
 			 p[0], dlerror () );
 		exit (1);
 	    }
-	    if ( ( new->u.function.func.m = dlsym (so->handle,p[1]) ) == NULL )
+	    if ( ( new->u.function.func.m =
+		   dlsym (new->u.function.so->handle, p[1]) ) == NULL )
 	    {
 		SYSLOG (LOG_ERR, "symbol: \"%s\" not found in %s\n",
 			p[1], p[0]);
@@ -1027,10 +1030,8 @@ static void action_call_function (const struct devfsd_notify_struct *info,
     argv[0] = (char *) entry->u.function.so->name;
     for (count = 1; entry->u.function.argv[count] != NULL; ++count)
     {
-	if (strcmp (entry->u.function.argv[count], "INFO") == 0)
+	if (strcmp (entry->u.function.argv[count], "EVENT") == 0)
 	    argv[count] = (char *) info;
-	else if (strcmp (entry->u.function.argv[count], "ENTRY") == 0)
-	    argv[count] = (char *) entry;
 	else
 	{
 	    st_expr_expand (largv[count], STRING_LENGTH,
